-- **************************************************************************
-- * TitanXP.lua
-- *
-- * By: Antalos
-- ******************************** Changelog ********************************
-- v1.04 - 4.0.1 compatibility, thanks to Hangar of Silvermoon
-- v1.02 - 3.3 compatibility, left click now opens PvP panel
-- v1.01 - added localization
-- v1.0 Aug 17, 2009 - first release
-- **************************************************************************

-- ******************************** Constants *******************************
local TITAN_HONOR_VER = "1.04";
local TITAN_HONOR_ID = "Honor";
local TITAN_HONOR_FREQUENCY = 1;
local updateTable = {TITAN_HONOR_ID, TITAN_PANEL_UPDATE_ALL};
-- ******************************** Variables *******************************
local TitanPanelHonorButton_ButtonAdded = nil;
local found = nil;
local lastMobXP = 0
local L = LibStub("AceLocale-3.0"):GetLocale("Titan_Honor", true)
-- ******************************** Functions *******************************

-- **************************************************************************
-- NAME : TitanPanelHonor_OnLoad()
-- DESC : Registers the plugin upon it loading
-- **************************************************************************
function TitanPanelHonorButton_OnLoad(self)
     self.registry = { 
          id = TITAN_HONOR_ID,
          builtIn = 1,
		  category = "Built-ins",
          version = TITAN_HONOR_VER,
          menuText = L["TITAN_HONOR_MENU_TEXT"],
          buttonTextFunction = "TitanPanelHonorButton_GetButtonText",
          tooltipTitle = L["TITAN_HONOR_TOOLTIP"],
          tooltipTextFunction = "TitanPanelHonorButton_GetTooltipText",
          iconWidth = 16,
          savedVariables = {       
            ShowIcon = 1,
            ShowHonor = 1,
            ShowConquestPoints = 1,
            ShowJusticePoints = 1,
            ShowLifetimeHK = 1,
          }
     };

end

-- **************************************************************************
-- NAME : TitanPanelHonorButton_OnShow()
-- DESC : Display the icon in the bar
-- NOTE : For a lack of better check at the moment TitanPanel_ButtonAdded
--        is a global variable set to true only when a button has just been
--        added to the panel
-- **************************************************************************
function TitanPanelHonorButton_OnShow()
     TitanPanelHonorButton_SetIcon();
     found = nil;
     if not TitanPanelHonorButton_ButtonAdded then
     		TitanPanelHonorButton_ButtonAdded = true;
     end
end


function TitanPanelHonorButton_OnHide()
	if (TitanPanelSettings) then
		for i = 1, table.getn(TitanPanelSettings.Buttons) do		
			if(TitanPanelSettings.Buttons[i] == TITAN_HONOR_ID) then
				found = true;			
			end	
		end
		if not found then
			TitanPanelHonorButton_ButtonAdded = nil
		end
	end
end

-- **************************************************************************
-- NAME : TitanPanelHonorButton_OnEvent(arg1, arg2)
-- DESC : Parse events registered to addon and act on them
-- VARS : arg1 = <research> , arg2 = <research>
-- **************************************************************************
function TitanPanelHonorButton_OnEvent(self, event, a1, a2, ...)
end

-- **************************************************************************
-- NAME : TitanPanelHonorButton_OnUpdate(elapsed)
-- DESC : Update button data
-- VARS : elapsed = <research>
-- **************************************************************************
function TitanPanelHonorButton_OnUpdate(self, elapsed)
     TITAN_HONOR_FREQUENCY = TITAN_HONOR_FREQUENCY - elapsed;
     if (TITAN_HONOR_FREQUENCY <= 0) then
          TITAN_HONOR_FREQUENCY = 1;
          TitanPanelPluginHandle_OnUpdate(updateTable)
     end
     if (self.totalTime) then
          self.totalTime = self.totalTime + elapsed;          
          self.levelTime = self.levelTime + elapsed;
     end
end


-- **************************************************************************
-- NAME : TitanPanelHonorButton_GetButtonText(id)
-- DESC : Calculate time based logic for button text
-- VARS : id = button ID
-- **************************************************************************
function TitanPanelHonorButton_GetButtonText(id)
    local button, id = TitanUtils_GetButton(id, true);
    local res = "";
    local my_arena_points = 0;
    local my_honor = 0;  
	local my_conquest_points = 0; 
    local my_justice_points = 0;
    local my_lifetime_hk = 0;  

	
    local localized_label, my_honor, icon_file_name = GetCurrencyInfo(392);
    local localized_label2, my_conquest_points, icon_file_name2 = GetCurrencyInfo(390);
    local localized_label3, my_justice_points, icon_file_name3 = GetCurrencyInfo(395);
	local my_lifetime_hk = select(1, GetPVPLifetimeStats());
	
	
    if (TitanGetVar(TITAN_HONOR_ID, "ShowHonor") ~= nil) then 
        res = res .. TitanHonor_HL_text(my_honor);
    end;
    if (TitanGetVar(TITAN_HONOR_ID, "ShowConquestPoints") ~= nil) then 
        res = res .. " "..L["TITAN_HONOR_CONQUEST_POINTS_SHORT"]..": " .. TitanHonor_HL_text(my_conquest_points);
    end;
    if (TitanGetVar(TITAN_HONOR_ID, "ShowJusticePoints") ~= nil) then 
        res = res .. " "..L["TITAN_HONOR_JUSTICE_POINTS_SHORT"]..": " .. TitanHonor_HL_text(my_justice_points);
    end;
    if (TitanGetVar(TITAN_HONOR_ID, "ShowLifetimeHK") ~= nil) then 
   		res = res .. " (" .. TitanHonor_HL_text(my_lifetime_hk) .." ".. L["TITAN_HONOR_LIFETIME_HK"] .. ")\n";
    end; 
    return res;
end

function TitanHonor_HL_text(text)
	if (text) then
        if (text == 0) then
            return GRAY_FONT_COLOR_CODE..text..FONT_COLOR_CODE_CLOSE;
        else 
            return HIGHLIGHT_FONT_COLOR_CODE..text..FONT_COLOR_CODE_CLOSE;
        end
	end
end

-- **************************************************************************
-- NAME : TitanPanelHonorButton_GetTooltipText()
-- DESC : Display tooltip text
-- **************************************************************************
function TitanPanelHonorButton_GetTooltipText()    
    local res = "";
    local my_honor = 0; 
    local my_conquest_points = 0;
    local my_justice_points = 0;
    local my_lifetime_hk = 0; 

    local localized_label, my_honor, icon_file_name = GetCurrencyInfo(392);
    local localized_label2, my_conquest_points, icon_file_name2 = GetCurrencyInfo(390);
    local localized_label3, my_justice_points, icon_file_name3 = GetCurrencyInfo(395);
		local my_lifetime_hk = select(1, GetPVPLifetimeStats());

    res = res .. L["TITAN_HONOR_HONOR"] .. ": " .. TitanHonor_HL_text(my_honor).."\n";
    res = res .. L["TITAN_HONOR_CONQUEST_POINTS"] .. ": " .. TitanHonor_HL_text(my_conquest_points).."\n";
    res = res .. L["TITAN_HONOR_JUSTICE_POINTS"] .. ": " .. TitanHonor_HL_text(my_justice_points).."\n";
    res = res .. L["TITAN_HONOR_LIFETIME_HK_TOOLTIP"] .. ": " .. TitanHonor_HL_text(my_lifetime_hk).."\n";
    --res = res .. "(" .. TitanHonor_HL_text(my_lifetime_hk) .." ".. L["TITAN_HONOR_LIFETIME_HK_TOOLTIP"] .. ")\n";
    
    return res;
end

-- **************************************************************************
-- NAME : TitanPanelHonorButton_SetIcon()
-- DESC : Define icon based on faction
-- **************************************************************************
function TitanPanelHonorButton_SetIcon()
     local icon = TitanPanelHonorButtonIcon;
     local factionGroup, factionName = UnitFactionGroup("player");     

     if (factionGroup == "Alliance") then
          icon:SetTexture("Interface\\TargetingFrame\\UI-PVP-Alliance");
          icon:SetTexCoord(0.046875, 0.609375, 0.03125, 0.59375);
     elseif (factionGroup == "Horde") then
          icon:SetTexture("Interface\\TargetingFrame\\UI-PVP-Horde");
          icon:SetTexCoord(0.046875, 0.609375, 0.015625, 0.578125);
     else
          icon:SetTexture("Interface\\TargetingFrame\\UI-PVP-FFA");
          icon:SetTexCoord(0.046875, 0.609375, 0.03125, 0.59375);
     end
end

-- **************************************************************************
-- NAME : TitanPanelRightClickMenu_PrepareXPMenu()
-- DESC : Display rightclick menu options
-- **************************************************************************
function TitanPanelRightClickMenu_PrepareHonorMenu()     
  
    local info = {};  
    TitanPanelRightClickMenu_AddTitle(TitanPlugins[TITAN_HONOR_ID].menuText);

    TitanPanelRightClickMenu_AddToggleVar(L["TITAN_HONOR_HONOR"], TITAN_HONOR_ID, "ShowHonor");    
    TitanPanelRightClickMenu_AddToggleVar(L["TITAN_HONOR_CONQUEST_POINTS"], TITAN_HONOR_ID, "ShowConquestPoints");    
    TitanPanelRightClickMenu_AddToggleVar(L["TITAN_HONOR_JUSTICE_POINTS"], TITAN_HONOR_ID, "ShowJusticePoints");    
    TitanPanelRightClickMenu_AddToggleVar(L["TITAN_HONOR_LIFETIME_HK"], TITAN_HONOR_ID, "ShowLifetimeHK");   
    
    TitanPanelRightClickMenu_AddSpacer();
    TitanPanelRightClickMenu_AddToggleIcon(TITAN_HONOR_ID);

    TitanPanelRightClickMenu_AddSpacer();
    TitanPanelRightClickMenu_AddCommand(L["TITAN_PANEL_MENU_HIDE"], TITAN_HONOR_ID, TITAN_PANEL_MENU_FUNC_HIDE);
  
end

-- **************************************************************************
-- NAME : TitanPanelHonorButton_OnClick()
-- DESC : Show PvP panel on left click
-- **************************************************************************
function TitanPanelHonorButton_OnClick(self, button)
     if (button == "LeftButton") then
		--PVPParentFrame:Show();
		TogglePVPFrame();
     end
end